@@ -18,9 +18,6 @@ import logging
 from telegram import (User, Message, Update, UserProfilePhotos, TelegramError,
                       ReplyMarkup, InputFile, TelegramObject)
 
-logging.basicConfig(
-    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
-
 
 class Bot(TelegramObject):
 
@@ -587,6 +584,8 @@ class Bot(TelegramObject):
         Returns:
           A JSON object.
         """
+        if method not in ('POST', 'GET'):
+            raise ValueError("Method '{}' is neither 'POST' nor 'GET'".format(method))
 
         if method == 'POST':
             try:
@@ -618,7 +617,6 @@ class Bot(TelegramObject):
             except URLError as e:
                 raise TelegramError(str(e))
 
-        return 0  # if not a POST or GET request
 
     def _parseAndCheckTelegram(self,
                                json_data):
